aboutsummaryrefslogtreecommitdiff
path: root/layers/core_validation.h
diff options
context:
space:
mode:
authorTobin Ehlis <tobine@google.com>2016-03-24 10:16:09 -0600
committerTobin Ehlis <tobine@google.com>2016-03-25 09:50:44 -0600
commit2f7e6c5bf2a7409cf4f29be1f4df8dade12e0a0b (patch)
treed1d31dac65964f2664656f84d64d8c089bb3fd68 /layers/core_validation.h
parent76d2d1b0d753faf972fe15bed32092702c21abb9 (diff)
downloadusermoji-2f7e6c5bf2a7409cf4f29be1f4df8dade12e0a0b.tar.xz
layers: Replace ptr-to-ptr descriptor data struct with vector
We were using GENERIC_HEADER** ppDescriptors to track updates to slots. This was pretty messy so make it a bit cleaner with a vector instead.
Diffstat (limited to 'layers/core_validation.h')
-rw-r--r--layers/core_validation.h12
1 files changed, 2 insertions, 10 deletions
diff --git a/layers/core_validation.h b/layers/core_validation.h
index c4a516d4..a157b43b 100644
--- a/layers/core_validation.h
+++ b/layers/core_validation.h
@@ -41,10 +41,6 @@
using std::vector;
-//#ifdef __cplusplus
-//extern "C" {
-//#endif
-
#if MTMERGE
// Mem Tracker ERROR codes
typedef enum _MEM_TRACK_ERROR {
@@ -618,11 +614,11 @@ class SET_NODE : public BASE_NODE {
GENERIC_HEADER *pUpdateStructs;
// Total num of descriptors in this set (count of its layout plus all prior layouts)
uint32_t descriptorCount;
- GENERIC_HEADER **ppDescriptors; // Array where each index points to update node for its slot
+ vector<GENERIC_HEADER*> pDescriptorUpdates; // Vector where each index points to update node for its slot
LAYOUT_NODE *pLayout; // Layout for this set
SET_NODE *pNext;
unordered_set<VkCommandBuffer> boundCmdBuffers; // Cmd buffers that this set has been bound to
- SET_NODE() : pUpdateStructs(NULL), ppDescriptors(NULL), pLayout(NULL), pNext(NULL){};
+ SET_NODE() : set(VK_NULL_HANDLE), pool(VK_NULL_HANDLE), pUpdateStructs(nullptr), pLayout(nullptr), pNext(nullptr){};
};
typedef struct _DESCRIPTOR_POOL_NODE {
@@ -896,7 +892,3 @@ class SWAPCHAIN_NODE {
}
~SWAPCHAIN_NODE() { delete[] pQueueFamilyIndices; }
};
-
-//#ifdef __cplusplus
-//}
-//#endif